safedns
    * ``auth_token`` Specify the api key to authenticate with


.. note::
   
   SafeDNS provider requires an API key in all interactions.
   You can generate one for your account on the following URL:
   https://my.ukfast.co.uk/applications/index.php

